"""Implements a HD44780 character LCD connected via PCF8574 on I2C.
   This code should work for at least esp8266 and (tested) Pyboard"""
import gc, micropython
from time import sleep_ms
gc.collect()
from machine import I2C
gc.collect()
micropython.mem_info(1)
from lcd_i2c8574 import I2cLcd
gc.collect()
micropython.mem_info(1)

PCF8574_ADDR = 0x27   # i2c address, may be changed by soldering connections

print("Running test_main")
i2c = I2C('Y', freq=100000)
lcd = I2cLcd(i2c, PCF8574_ADDR, 4, 20)
lcd.putstr("It Works!\nSecond Line")
sleep_ms(1000)
print("LCD Backlight off")
lcd.backlight_off()
sleep_ms(1000)
print("LCD Backlight on")
lcd.backlight_on()
sleep_ms(1000)
print("LCD Blink Cursor on")
lcd.blink_cursor()
sleep_ms(1000)
print("LCD Blink Cursor off")
lcd.show_cursor()
sleep_ms(1000)
lcd.putstr("\nThird Line\nFourth Line works...")
sleep_ms(1000)
print("LCD hide Cursor")
lcd.hide_cursor();
sleep_ms(1000)
lcd.clear()

print("LCD write custom Characters")
# smiley faces as custom characters
happy = bytearray([0x00,0x0A,0x00,0x04,0x00,0x11,0x0E,0x00])
sad = bytearray([0x00,0x0A,0x00,0x04,0x00,0x0E,0x11,0x00])
grin = bytearray([0x00,0x00,0x0A,0x00,0x1F,0x11,0x0E,0x00])
shock = bytearray([0x0A,0x00,0x04,0x00,0x0E,0x11,0x11,0x0E])
meh = bytearray([0x00,0x0A,0x00,0x04,0x00,0x1F,0x00,0x00])
angry = bytearray([0x11,0x0A,0x11,0x04,0x00,0x0E,0x11,0x00])
tongue = bytearray([0x00,0x0A,0x00,0x04,0x00,0x1F,0x05,0x02])
lcd.custom_char(0, happy)
lcd.custom_char(1, sad)
lcd.custom_char(2, grin)
lcd.custom_char(3, shock)
lcd.custom_char(4, meh)
lcd.custom_char(5, angry)
lcd.custom_char(6, tongue)

lcd.putstr("Custom chars:\n\n")
for i in range(7):
    lcd.putchar(" ")
    lcd.putchar(chr(i))
    sleep_ms(200)

sleep_ms(1000)
lcd.clear()

print("LCD write at (0,0)-Position")
lcd.move_to(0, 0)
lcd.putstr("Here at (0,0)")
sleep_ms(2000)
lcd.clear()
print("LCD write at (5,3)-Position")
lcd.move_to(5, 3)
lcd.putstr("Here at (5,3)")
sleep_ms(5000)
lcd.clear()

